---
id: 20211123215950
title: Insert zettel title as top heading if not done
tags: [zettel, markdown]
---
To get consistently looking cards, zettel's title will be inserted in `<h1>` tag in case it is missing in zettel's body.

First, the title from yaml frontmatter (`title:` key) will be used.

If this is missing too, then the filename will be used.
